Documentation
¶
Overview ¶
Package client provides a Stripe client for invoking APIs across all resources
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type API ¶ added in v1.0.1
type API struct {
// Charges is the client used to invoke /charges APIs.
// For more details see https://stripe.com/docs/api#charges.
Charges *charge.Client
// Customers is the client used to invoke /customers APIs.
// For more details see https://stripe.com/docs/api#customers.
Customers *customer.Client
// Cards is the client used to invoke /cards APIs.
// For more details see https://stripe.com/docs/api#cards.
Cards *card.Client
// Subs is the client used to invoke /subscriptions APIs.
// For more details see https://stripe.com/docs/api#subscriptions.
Subs *sub.Client
// Plans is the client used to invoke /plans APIs.
// For more details see https://stripe.com/docs/api#plans.
Plans *plan.Client
// Coupons is the client used to invoke /coupons APIs.
// For more details see https://stripe.com/docs/api#coupons.
Coupons *coupon.Client
// Discounts is the client used to invoke discount-related APIs.
// For mode details see https://stripe.com/docs/api#discounts.
Discounts *discount.Client
// Invoices is the client used to invoke /invoices APIs.
// For more details see https://stripe.com/docs/api#invoices.
Invoices *invoice.Client
// InvoiceItems is the client used to invoke /invoiceitems APIs.
// For more details see https://stripe.com/docs/api#invoiceitems.
InvoiceItems *invoiceitem.Client
// Disputes is the client used to invoke dispute-related APIs.
// For more details see https://stripe.com/docs/api#disputes.
Disputes *dispute.Client
// Transfers is the client used to invoke /transfers APIs.
// For more details see https://stripe.com/docs/api#transfers.
Transfers *transfer.Client
// Recipients is the client used to invoke /recipients APIs.
// For more details see https://stripe.com/docs/api#recipients.
Recipients *recipient.Client
// Refunds is the client used to invoke /refunds APIs.
// For more details see https://stripe.com/docs/api#refunds.
Refunds *refund.Client
// Fees is the client used to invoke /application_fees APIs.
// For more details see https://stripe.com/docs/api#application_fees.
Fees *fee.Client
// FeeRefunds is the client used to invoke /application_fees/refunds APIs.
// For more details see https://stripe.com/docs/api#fee_refundss.
FeeRefunds *feerefund.Client
// Account is the client used to invoke /account APIs.
// For more details see https://stripe.com/docs/api#account.
Account *account.Client
// CountrySpec is the client used to invoke /country_specs APIs.
// For more details see https://stripe.com/docs/api#country_specs.
CountrySpec *countryspec.Client
// Balance is the client used to invoke /balance and transaction-related APIs.
// For more details see https://stripe.com/docs/api#balance.
Balance *balance.Client
// Events is the client used to invoke /events APIs.
// For more details see https://stripe.com/docs/api#events.
Events *event.Client
// Tokens is the client used to invoke /tokens APIs.
// For more details see https://stripe.com/docs/api#tokens.
Tokens *token.Client
// FileUploads is the client used to invoke the uploads /files APIs.
// For more details see https://stripe.com/docs/api#file_uploads.
FileUploads *fileupload.Client
// BitcoinReceivers is the client used to invoke /bitcoin/receivers APIs.
// For more details see https://stripe.com/docs/api#bitcoin_receivers.
BitcoinReceivers *bitcoinreceiver.Client
// BitcoinTransactions is the client used to invoke /bitcoin/transactions APIs.
// For more details see https://stripe.com/docs/api#bitcoin_receivers.
BitcoinTransactions *bitcointransaction.Client
// Reversals is the client used to invoke /transfers/reversals APIs.
Reversals *reversal.Client
// BankAccounts is the client used to invoke /accounts/bank_accounts APIs.
BankAccounts *bankaccount.Client
// Products is the client used to invoke /products APIs.
// For more details see https://stripe.com/docs/api#products.
Products *product.Client
// Orders is the client used to invoke /orders APIs.
// For more details see https://stripe.com/docs/api#orders.
Orders *order.Client
// Skus is the client used to invoke /skus APIs.
// For more details see https://stripe.com/docs/api#skus.
Skus *sku.Client
}
API is the Stripe client. It contains all the different resources available.
Click to show internal directories.
Click to hide internal directories.